Module message

Module message 

Wire protocol types.

Structs

PeerCapability
What a peer claims to be able to do. Free-form so federated-learning extensions can introduce new capability strings without a wire-format change.

Enums

PeerMessage
One message on the mesh.

Type Aliases

PeerId
Stable peer identifier (human-chosen or auto-generated UUID).